@@ -12,19 +12,17 @@ from .midi_tokenizer_base import MIDITokenizer, Vocabulary, Event, detect_chords
 from .constants import *
 
 
-class MIDILikeEncoding(MIDITokenizer):
-    """ Structured MIDI encoding method as using in the Piano Inpainting Application
-    https://arxiv.org/abs/2107.05944
-    The token types follows the specific pattern:
-    Pitch -> Velocity -> Duration -> Time shift -> back to Pitch ...
-    NOTE: this encoding uses only "Time Shifts" events to move in the time, and only
+class MIDILike(MIDITokenizer):
+    """ MIDI-Like encoding, used with Music Transformer or MT3
+    https://arxiv.org/abs/1808.03715
+    This strategy simply convert MIDI messages into distinct tokens.
+    The token types are then Note-On, Velocity, Note-Off and Time-Shift
+    (+ the additional token types of MidiTok if desired).
+    NOTE: as this encoding uses only "Time Shifts" events to move in the time, and only
     from one note to another. Hence it is suitable to encode continuous sequences of
     notes without long periods of silence. If your dataset contains music with long
     pauses, you might handle them with an appropriate "time shift" dictionary
     (which values are made from the beat_res dict) or with a different encoding.
-    NOTE: the original Structured MIDI Encoding doesn't use Chords tokens as its
-    purpose is to draw uniform token types transitions, you can still use them but
-    it will "break" this property
 
     :param pitch_range: range of used MIDI pitches
     :param beat_res: beat resolutions, with the form:
@@ -216,7 +214,7 @@ class MIDILikeEncoding(MIDITokenizer):
         vocab.add_event(f'Velocity_{i}' for i in self.velocities)
 
         # TIME SHIFTS
-        vocab.add_event(f'Time-Shift_{".".join(map(str, self.durations[i]))}' for i in range(len(self.durations)))
+        vocab.add_event(f'Time-Shift_{".".join(map(str, duration))}' for duration in self.durations)
 
         # CHORD
         if self.additional_tokens['Chord']:
@@ -273,9 +271,10 @@ class MIDILikeEncoding(MIDITokenizer):
                 dic['Rest'] += ['Chord']
             dic['Note-Off'] += ['Rest']
 
+        self._add_pad_type_to_graph(dic)
         return dic
 
-    def token_types_errors(self, tokens: List[List[int]]) -> float:
+    def token_types_errors(self, tokens: List[int], consider_pad: bool = False) -> float:
         """ Checks if a sequence of tokens is constituted of good token types
         successions and returns the error ratio (lower is better).
         The Pitch and Position values are also analyzed:
@@ -283,14 +282,17 @@ class MIDILikeEncoding(MIDITokenizer):
             - a Note-Off token should not be present the note is not being played
 
         :param tokens: sequence of tokens to check
+        :param consider_pad: if True will continue the error detection after the first PAD token (default: False)
         :return: the error ratio (lower is better)
         """
         err = 0
         previous_type = self.vocab.token_type(tokens[0])
         current_pitches = []
 
-        for token in tokens[1:]:
-            token_type, token_value = self.vocab.token_to_event[token].split('_')
+        def check(tok: int):
+            nonlocal err
+            nonlocal previous_type
+            token_type, token_value = self.vocab.token_to_event[tok].split('_')
 
             # Good token type
             if token_type in self.tokens_types_graph[previous_type]:
@@ -307,8 +309,16 @@ class MIDILikeEncoding(MIDITokenizer):
             # Bad token type
             else:
                 err += 1
-
             previous_type = token_type
+
+        if consider_pad:
+            for token in tokens[1:]:
+                check(token)
+        else:
+            for token in tokens[1:]:
+                if previous_type == 'PAD':
+                    break
+                check(token)
         return err / len(tokens)
 
     @staticmethod
