@@ -12,7 +12,7 @@ from .midi_tokenizer_base import MIDITokenizer, Vocabulary, Event, detect_chords
 from .constants import *
 
 
-class REMIEncoding(MIDITokenizer):
+class REMI(MIDITokenizer):
     """ MIDI encoding method, similar to the REMI introduced in the Pop Music Transformer paper
     https://arxiv.org/abs/2002.00212
 
@@ -261,9 +261,10 @@ class REMIEncoding(MIDITokenizer):
             dic['Rest'] = ['Rest', 'Position', 'Bar']
             dic['Duration'] += ['Rest']
 
+        self._add_pad_type_to_graph(dic)
         return dic
 
-    def token_types_errors(self, tokens: List[int]) -> float:
+    def token_types_errors(self, tokens: List[int], consider_pad: bool = False) -> float:
         """ Checks if a sequence of tokens is constituted of good token types
         successions and returns the error ratio (lower is better).
         The Pitch and Position values are also analyzed:
@@ -271,6 +272,7 @@ class REMIEncoding(MIDITokenizer):
             - a pitch token should not be present if the same pitch is already played at the current position
 
         :param tokens: sequence of tokens to check
+        :param consider_pad: if True will continue the error detection after the first PAD token (default: False)
         :return: the error ratio (lower is better)
         """
         err = 0
@@ -278,8 +280,12 @@ class REMIEncoding(MIDITokenizer):
         current_pos = -1
         current_pitches = []
 
-        for token in tokens[1:]:
-            token_type, token_value = self.vocab.token_to_event[token].split('_')
+        def check(tok: int):
+            nonlocal err
+            nonlocal previous_type
+            nonlocal current_pos
+            nonlocal current_pitches
+            token_type, token_value = self.vocab.token_to_event[tok].split('_')
 
             # Good token type
             if token_type in self.tokens_types_graph[previous_type]:
@@ -300,8 +306,16 @@ class REMIEncoding(MIDITokenizer):
             # Bad token type
             else:
                 err += 1
-
             previous_type = token_type
+
+        if consider_pad:
+            for token in tokens[1:]:
+                check(token)
+        else:
+            for token in tokens[1:]:
+                if previous_type == 'PAD':
+                    break
+                check(token)
         return err / len(tokens)
 
     @staticmethod
